==> node-jasmine_4.0.2+~cs7.10.3.orig.tar.gz: jasmine-npm-4.0.2/README.md <==
[![Build Status](https://circleci.com/gh/jasmine/jasmine-npm.svg?style=shield)](https://circleci.com/gh/jasmine/jasmine-npm)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm?ref=badge_shield)

# The Jasmine Module

The `jasmine` module is a command line interface and supporting code for running
[Jasmine](https://github.com/jasmine/jasmine) specs under Node.

The core of jasmine lives at https://github.com/jasmine/jasmine and is `jasmine-core` in npm.

## Contents

This module allows you to run Jasmine specs for your Node.js code. The output will be displayed in your terminal by default.

## Documentation

https://jasmine.github.io/setup/nodejs.html

## Quick Start

Installation:

```sh
npm install --save-dev jasmine
```

To initialize a project for Jasmine:

```sh
npx jasmine init
````

To seed your project with some examples:

```sh
npx jasmine examples
````

To run your test suite:

```sh
npx jasmine
````

## ES and CommonJS module compatibility

Jasmine is compatible with both ES modules and CommonJS modules. See the 
[setup guide](https://jasmine.github.io/setup/nodejs.html) for more information.


## Node version compatibility

Jasmine supports Node 12.x where x >=17, Node 14, and Node 16.

## Support

Documentation: [jasmine.github.io](https://jasmine.github.io)
Jasmine Mailing list: [jasmine-js@googlegroups.com](mailto:jasmine-js@googlegroups.com)
Twitter: [@jasminebdd](http://twitter.com/jasminebdd)

Please file issues here at Github

Copyright (c) 2008-2017 Pivotal Labs. This software is licensed under the MIT License.


## License
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm?ref=badge_large)

==> node-jasmine_4.5.0+~cs8.8.0.orig.tar.gz: jasmine-npm-4.5.0/README.md <==
[![Build Status](https://circleci.com/gh/jasmine/jasmine-npm.svg?style=shield)](https://circleci.com/gh/jasmine/jasmine-npm)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm?ref=badge_shield)

# The Jasmine Module

The `jasmine` module is a command line interface and supporting code for running
[Jasmine](https://github.com/jasmine/jasmine) specs under Node.

The core of jasmine lives at https://github.com/jasmine/jasmine and is `jasmine-core` in npm.

## Contents

This module allows you to run Jasmine specs for your Node.js code. The output will be displayed in your terminal by default.

## Documentation

https://jasmine.github.io/setup/nodejs.html

## Quick Start

Installation:

```sh
npm install --save-dev jasmine
```

To initialize a project for Jasmine:

```sh
npx jasmine init
````

To seed your project with some examples:

```sh
npx jasmine examples
````

To run your test suite:

```sh
npx jasmine
````

## ES and CommonJS module compatibility

Jasmine is compatible with both ES modules and CommonJS modules. See the 
[setup guide](https://jasmine.github.io/setup/nodejs.html) for more information.


## Node version compatibility

Jasmine supports Node 18, 16, 14, and 12.17-12.22.

## Support

Documentation: [jasmine.github.io](https://jasmine.github.io)
Jasmine Mailing list: [jasmine-js@googlegroups.com](mailto:jasmine-js@googlegroups.com)
Twitter: [@jasminebdd](http://twitter.com/jasminebdd)

Please file issues here at Github

Copyright (c) 2008-2017 Pivotal Labs. This software is licensed under the MIT License.


## License
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fjasmine%2Fjasmine-npm?ref=badge_large)
